import * as _solana_web3_js from '@solana/web3.js';
import { ClusterUrl, createSolanaRpc, createSolanaRpcSubscriptions } from '@solana/web3.js';

/** Solana cluster moniker */
type SolanaClusterMoniker = "mainnet-beta" | "devnet" | "testnet" | "localnet";
type CreateSolanaClientArgs<TClusterUrl extends ClusterUrl> = {
    /** Full RPC URL (for a private RPC endpoint) or the Solana moniker (for a public RPC endpoint) */
    urlOrMoniker: TClusterUrl | URL | SolanaClusterMoniker;
    /** Configuration used to create the `rpc` client */
    rpcConfig?: Parameters<typeof createSolanaRpc<TClusterUrl>>[1];
    /** Configuration used to create the `rpcSubscriptions` client */
    rpcSubscriptionsConfig?: Parameters<typeof createSolanaRpcSubscriptions<TClusterUrl>>[1];
};
type CreateSolanaClientResult<TClusterUrl extends ClusterUrl> = {
    /** Newly created Solana RPC client  */
    rpc: ReturnType<typeof createSolanaRpc<TClusterUrl>>;
    /** Newly created Solana RPC subscriptions client */
    rpcSubscriptions: ReturnType<typeof createSolanaRpcSubscriptions<TClusterUrl>>;
};

/** 1 billion lamports SOL */
declare const LAMPORTS_PER_SOL = 1000000000;

/**
 * Get a public Solana RPC endpoint for a cluster based on its moniker
 *
 * Note: These RPC URLs are rate limited and not suitable for production applications.
 */
declare function getPublicSolanaRpcUrl(cluster: SolanaClusterMoniker): string;
/**
 * Create a Solana `rpc` and `rpcSubscriptions` client
 */
declare function createSolanaClient<TClusterUrl extends ClusterUrl>({ urlOrMoniker, rpcConfig, rpcSubscriptionsConfig, }: CreateSolanaClientArgs<TClusterUrl>): {
    rpc: _solana_web3_js.RpcFromTransport<_solana_web3_js.SolanaRpcApiFromTransport<_solana_web3_js.RpcTransportFromClusterUrl<TClusterUrl>>, _solana_web3_js.RpcTransportFromClusterUrl<TClusterUrl>>;
    rpcSubscriptions: _solana_web3_js.RpcSubscriptionsFromTransport<_solana_web3_js.SolanaRpcSubscriptionsApi, _solana_web3_js.RpcSubscriptionsTransportFromClusterUrl<TClusterUrl>>;
};

export { type CreateSolanaClientArgs, type CreateSolanaClientResult, LAMPORTS_PER_SOL, type SolanaClusterMoniker, createSolanaClient, getPublicSolanaRpcUrl };
