'use strict';

var web3_js = require('@solana/web3.js');

// src/core/const.ts
var LAMPORTS_PER_SOL = 1e9;
function getPublicSolanaRpcUrl(cluster) {
  switch (cluster) {
    case "devnet":
      return "https://api.devnet.solana.com";
    case "testnet":
      return "https://api.tesnet.solana.com";
    case "mainnet-beta":
      return "https://api.mainnet-beta.solana.com";
    case "localnet":
      return "http://127.0.0.1:8899";
    default:
      throw new Error("Invalid cluster moniker");
  }
}
function createSolanaClient({
  urlOrMoniker,
  rpcConfig,
  rpcSubscriptionsConfig
}) {
  if (typeof urlOrMoniker == "string") {
    try {
      urlOrMoniker = new URL(
        getPublicSolanaRpcUrl(urlOrMoniker)
      );
    } catch (err) {
      throw new Error("Invalid URL or cluster moniker");
    }
  }
  const rpc = web3_js.createSolanaRpc(
    urlOrMoniker.toString(),
    rpcConfig
  );
  if (urlOrMoniker.protocol.endsWith("s")) urlOrMoniker.protocol = "wss";
  else urlOrMoniker.protocol = "ws";
  const rpcSubscriptions = web3_js.createSolanaRpcSubscriptions(
    urlOrMoniker.toString(),
    rpcSubscriptionsConfig
  );
  return {
    rpc,
    rpcSubscriptions
  };
}

exports.LAMPORTS_PER_SOL = LAMPORTS_PER_SOL;
exports.createSolanaClient = createSolanaClient;
exports.getPublicSolanaRpcUrl = getPublicSolanaRpcUrl;
//# sourceMappingURL=index.node.cjs.map
//# sourceMappingURL=index.node.cjs.map