import { resolve } from 'node:path';
import { readFileSync } from 'node:fs';
import { homedir } from 'node:os';
import { createSignerFromKeyPair, createKeyPairFromBytes } from '@solana/web3.js';

// src/node/const.ts
var DEFAULT_CLI_KEYPAIR_PATH = "~/.config/solana/id.json";
async function loadKeypairSignerFromFile(filePath = DEFAULT_CLI_KEYPAIR_PATH) {
  const keypair = await loadKeypairFromFile(filePath);
  return createSignerFromKeyPair(keypair);
}
async function loadKeypairFromFile(filePath = DEFAULT_CLI_KEYPAIR_PATH) {
  const resolvedPath = resolve(
    filePath.startsWith("~") ? filePath.replace("~", homedir()) : filePath
  );
  return createKeyPairFromBytes(
    Uint8Array.from(JSON.parse(readFileSync(resolvedPath, "utf8")))
  );
}

export { DEFAULT_CLI_KEYPAIR_PATH, loadKeypairFromFile, loadKeypairSignerFromFile };
//# sourceMappingURL=index.node.mjs.map
//# sourceMappingURL=index.node.mjs.map